@@ -46,6 +46,11 @@ class GetAggregateResourceCountsGroupByResourceTypeRequest(RpcRequest):
 
 	def set_FolderId(self, FolderId):  # String
 		self.add_query_param('FolderId', FolderId)
+	def get_ResourceAccountId(self): # Long
+		return self.get_query_params().get('ResourceAccountId')
+
+	def set_ResourceAccountId(self, ResourceAccountId):  # Long
+		self.add_query_param('ResourceAccountId', ResourceAccountId)
 	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
