@@ -51,6 +51,11 @@ class ListAggregateConfigRuleEvaluationResultsRequest(RpcRequest):
 
 	def set_AggregatorId(self, AggregatorId):  # String
 		self.add_query_param('AggregatorId', AggregatorId)
+	def get_ResourceAccountId(self): # Long
+		return self.get_query_params().get('ResourceAccountId')
+
+	def set_ResourceAccountId(self, ResourceAccountId):  # Long
+		self.add_query_param('ResourceAccountId', ResourceAccountId)
 	def get_NextToken(self): # String
 		return self.get_query_params().get('NextToken')
 
