@@ -32,6 +32,11 @@ class UpdateAggregateCompliancePackRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_TagKeyScope(self): # String
+		return self.get_body_params().get('TagKeyScope')
+
+	def set_TagKeyScope(self, TagKeyScope):  # String
+		self.add_body_params('TagKeyScope', TagKeyScope)
 	def get_CompliancePackName(self): # String
 		return self.get_body_params().get('CompliancePackName')
 
@@ -52,6 +57,16 @@ class UpdateAggregateCompliancePackRequest(RpcRequest):
 
 	def set_AggregatorId(self, AggregatorId):  # String
 		self.add_body_params('AggregatorId', AggregatorId)
+	def get_TagValueScope(self): # String
+		return self.get_body_params().get('TagValueScope')
+
+	def set_TagValueScope(self, TagValueScope):  # String
+		self.add_body_params('TagValueScope', TagValueScope)
+	def get_RegionIdsScope(self): # String
+		return self.get_body_params().get('RegionIdsScope')
+
+	def set_RegionIdsScope(self, RegionIdsScope):  # String
+		self.add_body_params('RegionIdsScope', RegionIdsScope)
 	def get_CompliancePackId(self): # String
 		return self.get_body_params().get('CompliancePackId')
 
@@ -67,3 +82,13 @@ class UpdateAggregateCompliancePackRequest(RpcRequest):
 
 	def set_RiskLevel(self, RiskLevel):  # Integer
 		self.add_body_params('RiskLevel', RiskLevel)
+	def get_ResourceGroupIdsScope(self): # String
+		return self.get_body_params().get('ResourceGroupIdsScope')
+
+	def set_ResourceGroupIdsScope(self, ResourceGroupIdsScope):  # String
+		self.add_body_params('ResourceGroupIdsScope', ResourceGroupIdsScope)
+	def get_ExcludeResourceIdsScope(self): # String
+		return self.get_body_params().get('ExcludeResourceIdsScope')
+
+	def set_ExcludeResourceIdsScope(self, ExcludeResourceIdsScope):  # String
+		self.add_body_params('ExcludeResourceIdsScope', ExcludeResourceIdsScope)
